#!/bin/sh
# File:        runPython.sh
# Copyright:   (c) 2001 The Regents of the University of California
# Description: set environment variables and run python
# Revision:    $Revision: 3473 $
# Date:        $Date: 2003-12-15 16:49:27 -0800 (Mon, 15 Dec 2003) $
#

case "`uname`" in
  CYGWIN*) cygwin=true;;
  *) cygwin=false;;
esac

PYTHONLIB=../../../runtime/sidl/.libs
PYTHONPATH=../../../runtime/python
LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$PYTHONLIB
SIDL_DLL_PATH="../libdecaf/libdecaf.scl;../hello-server/libHelloServer.scl;../hello-client/libHelloClient.scl"
export PYTHONPATH SIDL_DLL_PATH LD_LIBRARY_PATH

if $cygwin; then
  PATH=$PATH:$PYTHONLIB
  export PATH
fi

python HelloDriver.py 
